#ifndef SWCONFIG_H
#define SWCONFIG_H

#include <stdio.h>

#include <string>
#include <map>


using namespace std;


typedef map <string, string, less <string> > ConfigEntMap;
typedef map <string, ConfigEntMap, less <string> > SectionMap;


class SWConfig {
private:
	char getline(FILE *fp, string &line);
public:
	string filename;
	SectionMap Sections;

	SWConfig(string ifilename);
	~SWConfig();

	void Load();
	void Save();
};

#endif
